<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.ApplicationModel.DataTransfer.DragDrop

Windows Runtime (WinRT) APIs for for the `Windows.ApplicationModel.DataTransfer.DragDrop` namespace.

This package provides the `winrt.windows.applicationmodel.datatransfer.dragdrop` module.
